==> Gridcoin-Research-5.3.3.0.tar.gz: Gridcoin-Research-5.3.3.0/src/qt/locale/bitcoin_es_UY.ts <==
<TS language="es_UY" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Double-click to edit address or label</source>
        <translation>Doble clic para editar etiqueta o dirección </translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>Crear una nueva dirección </translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>Nuevo</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Copia la dirección seleccionada al portapapeles del sistema</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Borrar</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Archivos separados por coma (*.csv)</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Direccion </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(Sin etiqueta)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Enter passphrase</source>
        <translation>Escriba la contraseña</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nueva contraseña</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Repetir nueva contraseña</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Monedero cifrado</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Esta operacion necesita la contraseña del monedero para desbloquear el mismo</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Monedero destrabado</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Esta operacion necesita la contraseña del monedero para descifrar el mismo</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Monedero descifrado</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Cambiar contraseña</translation>
    </message>
    <message>
        <source>Enter the old and new passphrase to the wallet.</source>
        <translation>Ingrese la contraseña anterior y la nueva de acceso a el monedero</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Confirme el cifrado del monedero</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Monedero cifrado</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Fallo en el cifrado del monedero</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Fallo en el cifrado del monedero a causa de un error interno. Su monedero no esta cifrado</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Las contraseñas suministradas no coinciden.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Fallo en el desbloqueo del mondero</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>La contraseña introducida para el descifrado del monedero es incorrecta.</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>Fallo en el descifrado del monedero</translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Vista previa</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Mostrar descripción general del monedero</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Buscar en el historial de transacciones</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>Salida</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Salir de la aplicacion </translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Opciones...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>Cambiar contraseña</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Cambie la clave utilizada para el cifrado del monedero</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Billetera</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>Mostrar / Ocultar</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Archivo</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Configuracion </translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ayuda</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>A la fecha</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message>
        <source>[testnet]</source>
        <translation>[prueba_de_red]</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Ponerse al dia...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Transaccion enviada</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Transacción entrante</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>El Monedero esta &lt;b&gt;cifrado&lt;/b&gt; y actualmente &lt;b&gt;bloqueado&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Cantidad:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>AMonto:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Cambio:</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Confirmado</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Direccion </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(Sin etiqueta)</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Editar dirección</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Etiqueta</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Direccion </translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>Nueva dirección de recepción </translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Nueva dirección de envío </translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Editar dirección de recepcion </translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Editar dirección de envío </translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>La dirección introducida "%1" ya está en la libreta de direcciones.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>No se puede abrir el monedero.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Fallo en la nueva clave generada.</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Formulario</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Information</source>
        <translation>Información</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Enviar monedas</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Cantidad:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>AMonto:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Enviar a varios destinatarios a la vez</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Confirmar el envío</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Confirmar el envio de monedas</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>La cantidad a pagar debe ser mayor que 0.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(Sin etiqueta)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>A&amp;Monto:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>Pagar &amp;A:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Etiqueta:</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Pegar la dirección desde el portapapeles</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>Introduzca una etiqueta para esta dirección para añadirla a su libreta de direcciones</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Pegar la dirección desde el portapapeles</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Abrir hasta %1</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>desconocido</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Direccion </translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Abrir hasta %1</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Archivos separados por coma (*.csv)</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Direccion </translation>
    </message>
    </context>
</TS>

==> Gridcoin-Research-5.4.9.0.tar.gz: Gridcoin-Research-5.4.9.0/src/qt/locale/bitcoin_es_UY.ts <==
<TS language="es_UY" version="2.0">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Crear una nueva dirección </translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>Nuevo</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Copia la dirección seleccionada al portapapeles del sistema</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Borrar</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Direccion </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(Sin etiqueta)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Enter passphrase</source>
        <translation>Escriba la contraseña</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nueva contraseña</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Repetir nueva contraseña</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Monedero cifrado</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Esta operacion necesita la contraseña del monedero para desbloquear el mismo</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Monedero destrabado</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Cambiar contraseña</translation>
    </message>
    <message>
        <source>Enter the old and new passphrase to the wallet.</source>
        <translation>Ingrese la contraseña anterior y la nueva de acceso a el monedero</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Confirme el cifrado del monedero</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Monedero cifrado</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Fallo en el cifrado del monedero</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Fallo en el cifrado del monedero a causa de un error interno. Su monedero no esta cifrado</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Las contraseñas suministradas no coinciden.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Fallo en el desbloqueo del mondero</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>La contraseña introducida para el descifrado del monedero es incorrecta.</translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Wallet</source>
        <translation>Billetera</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Vista previa</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Mostrar descripción general del monedero</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Buscar en el historial de transacciones</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>Salida</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Salir de la aplicacion </translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Opciones...</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>Mostrar / Ocultar</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>Cambiar contraseña</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Cambie la clave utilizada para el cifrado del monedero</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Archivo</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Configuracion </translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ayuda</translation>
    </message>
    <message>
        <source>[testnet]</source>
        <translation>[prueba_de_red]</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>A la fecha</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Ponerse al dia...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Transaccion enviada</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Transacción entrante</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>El Monedero esta &lt;b&gt;cifrado&lt;/b&gt; y actualmente &lt;b&gt;bloqueado&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Cantidad:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>AMonto:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Cambio:</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Confirmado</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Direccion </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(Sin etiqueta)</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Editar dirección</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Etiqueta</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Direccion </translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>Nueva dirección de recepción </translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Nueva dirección de envío </translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Editar dirección de recepcion </translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Editar dirección de envío </translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>La dirección introducida "%1" ya está en la libreta de direcciones.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>No se puede abrir el monedero.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Fallo en la nueva clave generada.</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Formulario</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Information</source>
        <translation>Información</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Enviar monedas</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Cantidad:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>AMonto:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Enviar a varios destinatarios a la vez</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Confirmar el envío</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Confirmar el envio de monedas</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>La cantidad a pagar debe ser mayor que 0.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(Sin etiqueta)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>A&amp;Monto:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>Pagar &amp;A:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Etiqueta:</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Pegar la dirección desde el portapapeles</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>Introduzca una etiqueta para esta dirección para añadirla a su libreta de direcciones</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Pegar la dirección desde el portapapeles</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Abrir hasta %1</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>desconocido</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Direccion </translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Abrir hasta %1</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Direccion </translation>
    </message>
    </context>
</TS>
